---
title: <span class="badge object-type-scalar"></span> DurationInHoursMinutesSeconds
---
# <span class="badge object-type-scalar"></span> DurationInHoursMinutesSeconds

Time: duration (hh:mm:ss)

## Definition

```python
# Time: duration (hh:mm:ss)
DurationInHoursMinutesSeconds: typing.Literal["dthms"] = "dthms"
```
